# nonebot-plugin-yulu
语录娱乐小插件

## 安装
```
pip install nonebot-plugin-yulu
```
------
```
nb plugin install nonebot-plugin-yulu
```
## 使用
请在evn文件里添加
```
yulu_on_group=["群号"] #配置开启群号
COMMAND_START=["/"] # 配置命令起始字符
```
bot.py加
```
nonebot.load_plugin("nonebot_plugin_yulu")
```
------
### 使用？bug？
启动之后 回复/菜单 即可使用

如果有bug请发issues

